==> nextcloud-23.0.7.tgz: nextcloud/apps/theming/l10n/is.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Hleð inn forskoðun...",
    "Admin" : "Stjórnandi",
    "Saved" : "Vistað",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Name cannot be empty" : "Heiti má ekki vera tómt",
    "The given name is too long" : "Uppgefið nafn er of langt",
    "The given web address is too long" : "Uppgefið veffang er of langt",
    "The given web address is not a valid URL" : "Uppgefið veffang er ekki gild vefslóð",
    "The given legal notice address is too long" : "Uppgefið veffang lagatexta er of langt",
    "The given legal notice address is not a valid URL" : "Uppgefið veffang lagatexta er ekki gild vefslóð",
    "The given privacy policy address is too long" : "Veffang á stefnu um meðferð persónulegra gagna er of langt",
    "The given privacy policy address is not a valid URL" : "Veffang á stefnu um meðferð persónulegra gagna er ekki gild vefslóð",
    "The given slogan is too long" : "Uppgefið slagorð er of langt",
    "The given color is invalid" : "Uppgefinn litur er ógildur",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded" : "Engin skrá var send inn",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Þú ert nú þegar að nota sérsniðið þema. Mögulega gæti það skrifað yfir stillingar í þemaforriti.",
    "Theming" : "Þemu",
    "Dark theme" : "Dökkt þema",
    "Enable dark theme" : "Virkja dökkt þema",
    "Dyslexia font" : "Dyslexia letur",
    "Enable dyslexia font" : "Virkja letur fyrir lesblinda",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic eru frjálsar leturgerðir sem eru hannaðar til að ráða bug á eða minnka vægi ýmissa villna sem stafa af lesblindu (dyslexia).",
    "High contrast mode" : "Mikil birtuskil",
    "Enable high contrast mode" : "Virkja ham með mikil birtuskil",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Þema með mikil birtuskil til að auðvelda vafur. Sjónræn gæði minnka en skýrleiki eykst",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Stefna um meðferð persónulegra gagna",
    "Adjust the Nextcloud theme" : "Laga Nextcloud þema",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Aðgengi fyrir alla er okkur mikilvægt. Við fylgjum vefstöðlum oggöngum úr skugga um að allt sé nothæft án þess að nota tölvumús, auk þess að hjálpartæki á borð við skjálesara virki. Við miðum að samhæfni við {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 á stigi AA, og höfum meira að segja háskerpuþemað miðað við stig AAA.",
    "Open documentation" : "Opna hjálparskjöl",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Þemu gera þér kleift að breyta útliti og hegðun þíns eintaks af viðmótinu auk studdra biðlaraforrita. Það verður sýnilegt öllum notendum.",
    "Name" : "Heiti",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Web link" : "Veftengill",
    "https://…" : "https://…",
    "Slogan" : "Slagorð",
    "Color" : "Litur",
    "Logo" : "Táknmerki",
    "Upload new logo" : "Senda inn nýtt táknmerki",
    "Login image" : "Innskráningarmynd",
    "Upload new login background" : "Senda inn nýjan bakgrunn innskráningar",
    "Remove background image" : "Fjarlægja bakgrunnsmynd",
    "Advanced options" : "Ítarlegir valkostir",
    "Legal notice link" : "Tengill á lagaleg atriði",
    "Privacy policy link" : "Tengill á stefnu um meðferð persónulegra gagna",
    "Header logo" : "Táknmerki í haus",
    "Upload new header logo" : "Senda inn nýtt táknmerki fyrir síðuhaus",
    "Favicon" : "Veftákn",
    "Upload new favicon" : "Senda inn nýja táknmynd",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Settu inn Imagemagick PHP forritsviðaukann með stuðningi við SVG-myndir til að útbúa sjálfvirkt veftáknmyndir byggðar á innsendu táknmerki og lit."
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-25.0.4.tgz: nextcloud/apps/theming/l10n/is.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Uppgefið nafn er of langt",
    "The given web address is too long" : "Uppgefið veffang er of langt",
    "The given web address is not a valid URL" : "Uppgefið veffang er ekki gild vefslóð",
    "The given legal notice address is too long" : "Uppgefið veffang lagatexta er of langt",
    "The given legal notice address is not a valid URL" : "Uppgefið veffang lagatexta er ekki gild vefslóð",
    "The given privacy policy address is too long" : "Veffang á stefnu um meðferð persónulegra gagna er of langt",
    "The given privacy policy address is not a valid URL" : "Veffang á stefnu um meðferð persónulegra gagna er ekki gild vefslóð",
    "The given slogan is too long" : "Uppgefið slagorð er of langt",
    "The given color is invalid" : "Uppgefinn litur er ógildur",
    "Saved" : "Vistað",
    "The file was uploaded" : "Skráin var send inn",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Innsend skrá er stærri en upload_max stillingin í php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Innsenda skráin er stærri en MAX_FILE_SIZE sem skilgreint er í HTML sniðinu",
    "The file was only partially uploaded" : "Einungis hluti af innsendri skrá skilaði sér",
    "No file was uploaded" : "Engin skrá skilaði sér",
    "Missing a temporary folder" : "Vantar bráðabirgðamöppu",
    "Could not write file to disk" : "Tókst ekki að skrifa skrá á disk.",
    "A PHP extension stopped the file upload" : "PHP-viðbót stöðvaði innsendingu skráar",
    "No file uploaded" : "Engin skrá var send inn",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Þú ert nú þegar að nota sérsniðið þema. Mögulega gæti það skrifað yfir stillingar í þemaforriti.",
    "Theming" : "Þemu",
    "Dark theme" : "Dökkt þema",
    "Enable dark theme" : "Virkja dökkt þema",
    "Dyslexia font" : "Dyslexia letur",
    "Enable dyslexia font" : "Virkja letur fyrir lesblinda",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic eru frjálsar leturgerðir sem eru hannaðar til að ráða bug á eða minnka vægi ýmissa villna sem stafa af lesblindu (dyslexia).",
    "High contrast mode" : "Mikil birtuskil",
    "Enable high contrast mode" : "Virkja ham með mikil birtuskil",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Þema með mikil birtuskil til að auðvelda vafur. Sjónræn gæði minnka en skýrleiki eykst",
    "Legal notice" : "Lagaleg atriði",
    "Privacy policy" : "Stefna um meðferð persónulegra gagna",
    "Adjust the Nextcloud theme" : "Laga Nextcloud þema",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Þemu gera þér kleift að breyta útliti og hegðun þíns eintaks af viðmótinu auk studdra biðlaraforrita. Það verður sýnilegt öllum notendum.",
    "Advanced options" : "Ítarlegir valkostir",
    "Name" : "Heiti",
    "Web link" : "Veftengill",
    "a safe home for all your data" : "öruggur staður fyrir öll gögnin þín",
    "Slogan" : "Slagorð",
    "Color" : "Litur",
    "Logo" : "Táknmerki",
    "Upload new logo" : "Senda inn nýtt táknmerki",
    "Legal notice link" : "Tengill á lagaleg atriði",
    "Privacy policy link" : "Tengill á stefnu um meðferð persónulegra gagna",
    "Header logo" : "Táknmerki í haus",
    "Upload new header logo" : "Senda inn nýtt táknmerki fyrir síðuhaus",
    "Favicon" : "Veftákn",
    "Upload new favicon" : "Senda inn nýja táknmynd",
    "User settings" : "Notandastillingar",
    "Keyboard shortcuts" : "Flýtileiðir á lyklaborði",
    "Background" : "Background",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Aðgengi fyrir alla er okkur mikilvægt. Við fylgjum vefstöðlum oggöngum úr skugga um að allt sé nothæft án þess að nota tölvumús, auk þess að hjálpartæki á borð við skjálesara virki. Við miðum að samhæfni við {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 á stigi AA, og höfum meira að segja háskerpuþemað miðað við stig AAA.",
    "Change color" : "Breyta lit",
    "Reset to default" : "Endurstilla á sjálfgefið",
    "Upload" : "Senda inn",
    "Remove background image" : "Fjarlægja bakgrunnsmynd",
    "Loading preview…" : "Hleð inn forskoðun...",
    "Admin" : "Stjórnandi",
    "Name cannot be empty" : "Heiti má ekki vera tómt",
    "Open documentation" : "Opna hjálparskjöl",
    "https://…" : "https://…",
    "Login image" : "Innskráningarmynd",
    "Upload new login background" : "Senda inn nýjan bakgrunn innskráningar",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Settu inn Imagemagick PHP forritsviðaukann með stuðningi við SVG-myndir til að útbúa sjálfvirkt veftáknmyndir byggðar á innsendu táknmerki og lit.",
    "Custom color" : "Sérsniðinn litur"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
